@@ -899,10 +899,23 @@ int xeve_config(XEVE id, int cfg, void * buf, int * size)
             ctx->param.qp = t0;
             break;
         case XEVE_CFG_SET_FPS:
-            xeve_assert_rv(*size == sizeof(int), XEVE_ERR_INVALID_ARGUMENT);
-            t0 = *((int *)buf);
-            xeve_assert_rv(t0 > 0, XEVE_ERR_INVALID_ARGUMENT);
-            ctx->param.fps = t0;
+            xeve_assert_rv(*size == sizeof(char*), XEVE_ERR_INVALID_ARGUMENT);
+            if (strpbrk((char*)buf, "/") != NULL)
+            {
+              sscanf((char*)buf, "%d/%d", &ctx->param.fps.num, &ctx->param.fps.den);
+            }
+            else if (strpbrk((char*)buf, ".") != NULL)
+            {
+              float tmp_fps = 0;
+              sscanf((char*)buf, "%f", &tmp_fps);
+              ctx->param.fps.num = tmp_fps * 10000;
+              ctx->param.fps.den = 10000;
+            }
+            else
+            {
+              sscanf((char*)buf, "%d", &ctx->param.fps.num);
+              ctx->param.fps.den = 1;
+            }
             break;
         case XEVE_CFG_SET_BPS:
             xeve_assert_rv(*size == sizeof(int), XEVE_ERR_INVALID_ARGUMENT);
@@ -968,8 +981,8 @@ int xeve_config(XEVE id, int cfg, void * buf, int * size)
             *((int *)buf) = ctx->param.h;
             break;
         case XEVE_CFG_GET_FPS:
-            xeve_assert_rv(*size == sizeof(int), XEVE_ERR_INVALID_ARGUMENT);
-            *((int *)buf) = ctx->param.fps;
+            xeve_assert_rv(*size == sizeof(char*), XEVE_ERR_INVALID_ARGUMENT);
+            sprintf((char*)buf, "%d/%d", ctx->param.fps.num, ctx->param.fps.den);
             break;
         case XEVE_CFG_GET_KEYINT:
             xeve_assert_rv(*size == sizeof(int), XEVE_ERR_INVALID_ARGUMENT);
